# pyinpe


[![image](https://img.shields.io/pypi/v/pyinpe.svg)](https://pypi.python.org/pypi/pyinpe)
[![image](https://img.shields.io/conda/vn/conda-forge/pyinpe.svg)](https://anaconda.org/conda-forge/pyinpe)


**A python package demo for environmental data**


-   Free software: MIT License
-   Documentation: https://luizsatolo.github.io/pyinpe
    

## Features

-   TODO
